# Change log

## v0.1.0 (2021-03-31)

### Features

* JSON data model
* JSON Pointer implementation
* JSON Schema implementation, supporting drafts 2019-09 and 2020-12 of the specification
* URI class (wraps rfc3986.URIReference)
